# Alchina /al.ki.na/

[![Build Status](https://travis-ci.org/matthieugouel/alchina.svg?branch=master)](https://travis-ci.org/matthieugouel/alchina)
[![Coverage Status](https://coveralls.io/repos/github/matthieugouel/alchina/badge.svg?branch=master)](https://coveralls.io/github/matthieugouel/alchina?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![license](https://img.shields.io/github/license/matthieugouel/gibica.svg)](https://github.com/matthieugouel/gibica/blob/master/LICENSE)

Alchina is a Machine Learning framework.
